[master 4/30] Use /usr/bin/python3 in scripts (#1014220)

M4rtinK installerbot-noreply at redhat.com
Mon Jun 1 14:04:21 UTC 2015


From: Martin Kolman <mkolman at redhat.com>

---
 anaconda                                         | 2 +-
 data/command-stubs/list-harddrives-stub          | 2 +-
 scripts/anaconda-cleanup                         | 2 +-
 scripts/analog                                   | 2 +-
 scripts/githooks/pre-commit                      | 2 +-
 scripts/instperf                                 | 2 +-
 scripts/makebumpver                              | 2 +-
 scripts/makeupdates                              | 2 +-
 tests/gettext/gettext_potfiles.py                | 2 +-
 tests/gettext/style_guide.py                     | 2 +-
 tests/glade/accelerators/check_accelerators.py   | 2 +-
 tests/glade/format_string/check_format_string.py | 2 +-
 tests/glade/icons/check_icons.py                 | 2 +-
 tests/glade/markup/check_markup.py               | 2 +-
 tests/glade/pw_visibility/check_pw_visibility.py | 2 +-
 tests/glade/validity/check_glade_validity.py     | 2 +-
 tests/glade/viewport/check_viewport.py           | 2 +-
 tests/gui/inside/__init__.py                     | 2 +-
 tests/gui/outside/__init__.py                    | 2 +-
 tests/gui/outside/test_reclaim.py                | 2 +-
 tests/gui/outside/test_simplelivecd.py           | 2 +-
 tests/pyanaconda_tests/ks_version_test.py        | 2 +-
 tests/pylint/runpylint.sh                        | 4 ++--
 tests/regex_tests/groupparse_test.py             | 2 +-
 tests/regex_tests/hostname_test.py               | 2 +-
 tests/regex_tests/repo_name_test.py              | 2 +-
 tests/regex_tests/username_test.py               | 2 +-
 tests/storage/cases/__init__.py                  | 2 +-
 tests/storage/cases/bz1014545.py                 | 2 +-
 tests/storage/cases/bz1067707.py                 | 2 +-
 tests/storage/cases/reuse.py                     | 2 +-
 tests/storage/run_storage_tests.py               | 2 +-
 utils/handle-sshpw                               | 2 +-
 33 files changed, 34 insertions(+), 34 deletions(-)

diff --git a/anaconda b/anaconda
index a6948d5..44f0545 100755
--- a/anaconda
+++ b/anaconda
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # anaconda: The Red Hat Linux Installation program
 #
diff --git a/data/command-stubs/list-harddrives-stub b/data/command-stubs/list-harddrives-stub
index 28274e4..2a763ac 100755
--- a/data/command-stubs/list-harddrives-stub
+++ b/data/command-stubs/list-harddrives-stub
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # scan system for harddrives and output device name/size
 #
diff --git a/scripts/anaconda-cleanup b/scripts/anaconda-cleanup
index ea3ebcd..632cee9 100755
--- a/scripts/anaconda-cleanup
+++ b/scripts/anaconda-cleanup
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 """
     always:
         - unmount everything under /mnt/sysimage
diff --git a/scripts/analog b/scripts/analog
index d2d68aa..9bf4564 100755
--- a/scripts/analog
+++ b/scripts/analog
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # analog: Remote logging manager for the Red Hat Installer
 #
diff --git a/scripts/githooks/pre-commit b/scripts/githooks/pre-commit
index 257155f..cea8b89 100755
--- a/scripts/githooks/pre-commit
+++ b/scripts/githooks/pre-commit
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 """ Run the Anaconda pylint tests on the files changed in this commit
 
     Set NOPYLINT env variable to skip this. eg. NOPYLINT= git commit
diff --git a/scripts/instperf b/scripts/instperf
index a4fe28a..b183352 100755
--- a/scripts/instperf
+++ b/scripts/instperf
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 import logging
 from subprocess import Popen, PIPE
diff --git a/scripts/makebumpver b/scripts/makebumpver
index 17709ff..b60e907 100755
--- a/scripts/makebumpver
+++ b/scripts/makebumpver
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # makebumpver - Increment version number and add in RPM spec file changelog
 #               block.  Ensures rhel*-branch commits reference RHEL bugs.
diff --git a/scripts/makeupdates b/scripts/makeupdates
index dd8a381..8605c76 100755
--- a/scripts/makeupdates
+++ b/scripts/makeupdates
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # makeupdates - Generate an updates.img containing changes since the last
 #               tag, but only changes to the main anaconda runtime.
diff --git a/tests/gettext/gettext_potfiles.py b/tests/gettext/gettext_potfiles.py
index 05c5ec9..480abbc 100755
--- a/tests/gettext/gettext_potfiles.py
+++ b/tests/gettext/gettext_potfiles.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 import os, sys, subprocess
 
diff --git a/tests/gettext/style_guide.py b/tests/gettext/style_guide.py
index f41369b..a4a52b6 100755
--- a/tests/gettext/style_guide.py
+++ b/tests/gettext/style_guide.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/glade/accelerators/check_accelerators.py b/tests/glade/accelerators/check_accelerators.py
index ec44d36..26b4159 100755
--- a/tests/glade/accelerators/check_accelerators.py
+++ b/tests/glade/accelerators/check_accelerators.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2013  Red Hat, Inc.
 #
diff --git a/tests/glade/format_string/check_format_string.py b/tests/glade/format_string/check_format_string.py
index ea213eb..b8833b5 100755
--- a/tests/glade/format_string/check_format_string.py
+++ b/tests/glade/format_string/check_format_string.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/glade/icons/check_icons.py b/tests/glade/icons/check_icons.py
index 4321a5b..e73c9ad 100755
--- a/tests/glade/icons/check_icons.py
+++ b/tests/glade/icons/check_icons.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/glade/markup/check_markup.py b/tests/glade/markup/check_markup.py
index b7619f8..d437384 100755
--- a/tests/glade/markup/check_markup.py
+++ b/tests/glade/markup/check_markup.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/glade/pw_visibility/check_pw_visibility.py b/tests/glade/pw_visibility/check_pw_visibility.py
index 6cbe8e2..6c5f115 100755
--- a/tests/glade/pw_visibility/check_pw_visibility.py
+++ b/tests/glade/pw_visibility/check_pw_visibility.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2013  Red Hat, Inc.
 #
diff --git a/tests/glade/validity/check_glade_validity.py b/tests/glade/validity/check_glade_validity.py
index 87445ec..1101472 100755
--- a/tests/glade/validity/check_glade_validity.py
+++ b/tests/glade/validity/check_glade_validity.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/glade/viewport/check_viewport.py b/tests/glade/viewport/check_viewport.py
index 337d00f..16480d3 100755
--- a/tests/glade/viewport/check_viewport.py
+++ b/tests/glade/viewport/check_viewport.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/gui/inside/__init__.py b/tests/gui/inside/__init__.py
index ca29684..0de6ecb 100644
--- a/tests/gui/inside/__init__.py
+++ b/tests/gui/inside/__init__.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/gui/outside/__init__.py b/tests/gui/outside/__init__.py
index c1e293a..35c02ff 100644
--- a/tests/gui/outside/__init__.py
+++ b/tests/gui/outside/__init__.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/gui/outside/test_reclaim.py b/tests/gui/outside/test_reclaim.py
index af21ffb..c4f4dbf 100644
--- a/tests/gui/outside/test_reclaim.py
+++ b/tests/gui/outside/test_reclaim.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/gui/outside/test_simplelivecd.py b/tests/gui/outside/test_simplelivecd.py
index 6d333da..2bc4349 100644
--- a/tests/gui/outside/test_simplelivecd.py
+++ b/tests/gui/outside/test_simplelivecd.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/pyanaconda_tests/ks_version_test.py b/tests/pyanaconda_tests/ks_version_test.py
index 26ab04a..259d509 100644
--- a/tests/pyanaconda_tests/ks_version_test.py
+++ b/tests/pyanaconda_tests/ks_version_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2013  Red Hat, Inc.
 #
diff --git a/tests/regex_tests/groupparse_test.py b/tests/regex_tests/groupparse_test.py
index 80e7187..75b4026 100644
--- a/tests/regex_tests/groupparse_test.py
+++ b/tests/regex_tests/groupparse_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2010-2013  Red Hat, Inc.
 #
diff --git a/tests/regex_tests/hostname_test.py b/tests/regex_tests/hostname_test.py
index df04327..eeb7442 100644
--- a/tests/regex_tests/hostname_test.py
+++ b/tests/regex_tests/hostname_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 # vim:set fileencoding=utf-8
 #
 # Copyright (C) 2014  Red Hat, Inc.
diff --git a/tests/regex_tests/repo_name_test.py b/tests/regex_tests/repo_name_test.py
index 76ac0f9..7e5a062 100644
--- a/tests/regex_tests/repo_name_test.py
+++ b/tests/regex_tests/repo_name_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 # vim:set fileencoding=utf-8
 #
 # Copyright (C) 2014  Red Hat, Inc.
diff --git a/tests/regex_tests/username_test.py b/tests/regex_tests/username_test.py
index b205945..aeffd05 100644
--- a/tests/regex_tests/username_test.py
+++ b/tests/regex_tests/username_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 # vim:set fileencoding=utf-8
 #
 # Copyright (C) 2010-2013  Red Hat, Inc.
diff --git a/tests/storage/cases/__init__.py b/tests/storage/cases/__init__.py
index 74b9467..5d20647 100644
--- a/tests/storage/cases/__init__.py
+++ b/tests/storage/cases/__init__.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2013-2014  Red Hat, Inc.
 #
diff --git a/tests/storage/cases/bz1014545.py b/tests/storage/cases/bz1014545.py
index 680b604..5076687 100644
--- a/tests/storage/cases/bz1014545.py
+++ b/tests/storage/cases/bz1014545.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2013-2014  Red Hat, Inc.
 #
diff --git a/tests/storage/cases/bz1067707.py b/tests/storage/cases/bz1067707.py
index 29a13b7..4dafa22 100644
--- a/tests/storage/cases/bz1067707.py
+++ b/tests/storage/cases/bz1067707.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/storage/cases/reuse.py b/tests/storage/cases/reuse.py
index b0007dd..d8463b5 100644
--- a/tests/storage/cases/reuse.py
+++ b/tests/storage/cases/reuse.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # Copyright (C) 2014  Red Hat, Inc.
 #
diff --git a/tests/storage/run_storage_tests.py b/tests/storage/run_storage_tests.py
index be0d199..74dbf5f 100755
--- a/tests/storage/run_storage_tests.py
+++ b/tests/storage/run_storage_tests.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 import os, sys
 
diff --git a/utils/handle-sshpw b/utils/handle-sshpw
index 281efe7..f6d0688 100755
--- a/utils/handle-sshpw
+++ b/utils/handle-sshpw
@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 #
 # handle-sshpw:  Code processing sshpw lines in kickstart files for the
 #                install environment.


diff --git a/tests/pylint/runpylint.sh b/tests/pylint/runpylint.sh
index 58e895d..4b89d1c 100755
--- a/tests/pylint/runpylint.sh
+++ b/tests/pylint/runpylint.sh
@@ -116,10 +116,10 @@ fi
 # run pylint one file / module at a time, otherwise it sometimes gets
 # confused
 if [ -z "$FILES" ]; then
     # Test any file that either ends in .py or contains #!/usr/bin/python2 in
     # the first line.
     FILES=$(findtestfiles \( -name '*.py' -o \
-                -exec /bin/sh -c "head -1 {} | grep -q '#!/usr/bin/python2'" \; \) -print)
+                -exec /bin/sh -c "head -1 {} | grep -q '#!/usr/bin/python3'" \; \) -print)
 fi
 
 # run pylint in paralel
@@ -116,10 +116,10 @@ fi
 # confused
 if [ -z "$FILES" ]; then
-    # Test any file that either ends in .py or contains #!/usr/bin/python2 in
+    # Test any file that either ends in .py or contains #!/usr/bin/python3 in
     # the first line.
     FILES=$(findtestfiles \( -name '*.py' -o \
-- 
To view this commit on github, visit https://github.com/rhinstaller/anaconda/commit/9c84767e8da319c4c4e6e1f871fccdcef118d92c


More information about the anaconda-patches mailing list